@@ -1,4 +1,4 @@
-from django.conf.urls import patterns, url
+from django.conf.urls import patterns, url, include
 
 from djangomaster.views.home import HomeView
 from djangomaster.views.routes import RoutesListView
