@@ -21,7 +21,8 @@ class Route(object):
 
     @property
     def app_name(self):
-        return getattr(self.obj, 'app_name', self._app_name)
+        _app_name = getattr(self.obj, 'app_name', None)
+        return _app_name or self._app_name
 
     @property
     def url(self):
